@@ -11,7 +11,8 @@ my $obj = Locale::Utils::PlaceholderMaketext->new;
 
 () = print {*STDOUT}
     Locale::Utils::PlaceholderMaketext
-        ->maketext_to_gettext('foo [_1] bar'),
+        ->new( is_escape_percent_sign => 1 )
+        ->maketext_to_gettext('foo % [_1] bar'),
     "\n",
     $obj->maketext_to_gettext('foo [_1] bar'),
     "\n",
@@ -28,8 +29,8 @@ __END__
 
 Output:
 
+foo %% %1 bar
 foo %1 bar
-foo %1 bar
-~ %% foo [%1] bar
+~ % foo [%1] bar
 foo %1 bar %quant(%2,singluar,plural,zero) baz
 bar %*(%2,singluar,plural) baz
