@@ -42,7 +42,7 @@ my $obj = Locale::Utils::PlaceholderMaketext->new;
     ),
     "\n";
 
-$obj->strict(1);
+$obj->is_strict(1);
 
 for (undef, 0 .. 2, '3234567.890', 4_234_567.890) { ## no critic (MagicNumbers)
     () = print
