@@ -27,7 +27,7 @@ my $obj = Locale::Utils::PlaceholderMaketext->new;
     ),
     "\n";
 
-$obj->strict(1);
+$obj->is_strict(1);
 
 for (undef, 0 .. 2, '3234567.890') {
     () = print
