@@ -9,9 +9,14 @@ use MooX::StrictConstructor;
 use MooX::Types::MooseLike::Base qw(Bool Str CodeRef);
 use namespace::autoclean;
 
-our $VERSION = '0.004';
+our $VERSION = '1.000';
 
-has strict => (
+has is_strict => (
+    is  => 'rw',
+    isa => Bool,
+);
+
+has is_escape_percent_sign => (
     is  => 'rw',
     isa => Bool,
 );
@@ -21,6 +26,7 @@ has space => (
     isa     => Str,
     default => q{ },
 );
+
 sub reset_space { return shift->space(q{ }) }
 
 has formatter_code => (
@@ -30,10 +36,11 @@ has formatter_code => (
 );
 
 sub maketext_to_gettext {
-    my (undef, $string) = @_;
+    my ($self, $string) = @_;
 
     defined $string
         or return $string;
+    my $is_escape_percent_sign  = $self->is_escape_percent_sign;
     ## no critic (ComplexRegexes)
     $string =~ s{
         [~] ( [~\[\]] )                      # $1 - unescape
@@ -55,7 +62,7 @@ sub maketext_to_gettext {
         $1
         ? $1
         : $2
-        ? "%$2"
+        ? $is_escape_percent_sign ? "%$2" : $2
         : $6
         ? "%$6"
         : "%$3(%$4$5)"
@@ -109,7 +116,7 @@ sub _replace { ## no critic (ManyArgs)
     if (defined $index_quant) { # quant
         my $number = $arg_ref->[$index_quant - 1];
         if ( ! looks_like_number($number) ) {
-            $number = $self->strict ? return $text : 0;
+            $number = $self->is_strict ? return $text : 0;
         }
         my $formatted
             = $self->formatter_code
@@ -136,7 +143,7 @@ sub _replace { ## no critic (ManyArgs)
     # replace only
     my $string = $arg_ref->[$index_string - 1];
     defined $string
-        or return $self->strict ? $text : q{};
+        or return $self->is_strict ? $text : q{};
 
     return
         $self->formatter_code
@@ -233,19 +240,21 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/Locale-Utils
 
 =head1 VERSION
 
-0.004
+1.000
 
 =head1 SYNOPSIS
 
     use Locale::Utils::PlaceholderMaketext;
 
     my $obj = Locale::Utils::PlaceholderMaketext->new(
-        # optional strict switch
-        strict         => 1,
+        # optional is_strict switch
+        is_strict              => 1,
+        # optional escape of % to %%
+        is_escape_percent_sign => 1,
         # optional fromatter code
-        formatter_code => sub { ... },
+        formatter_code         => sub { ... },
         # space between number and singular/plural at function quant
-        space          => "\N{NO-BREAK SPACE}",
+        space                  => "\N{NO-BREAK SPACE}",
     );
 
     $expanded = $obj->expand_maketext($text, @args);
@@ -268,6 +277,7 @@ Use method sapce to prevent the linebreak bitween number and singular/plural.
 
 Maps maketext strings with
 
+ %
  [_1]
  [quant,_2,singular]
  [quant,_3,singular,plural]
@@ -278,6 +288,7 @@ Maps maketext strings with
 
 inside to
 
+ %%
  %1
  %quant(%2,singluar)
  %quant(%3,singluar,plural)
@@ -287,6 +298,7 @@ inside to
  %*(%7,singluar,plural,zero)
 
 inside.
+% to %% depends on is_escape_percent_sign
 
     $gettext_string = $obj->maketext_to_gettext($maketext_string);
 
@@ -315,13 +327,20 @@ The default of space is C<q{ }>.
     $obj->space( "\N{NO-BREAK SPACE}" ); # unicode example
     $obj->reset_space; # to reset to the default q{ }
 
-=head2 method strict
+=head2 method is_strict
 
-If strict is true:
+If is_strict is true:
 For normal replacement undef will be converted to q{}.
 For quant undef will be converted to 0.
 
-    $obj->strict(1); # boolean true or false;
+    $obj->is_strict(1); # boolean true or false;
+
+=head2 method is_escape_percent_sign
+
+If is_ecscpe_percent_sign is true:
+A single % willbe escaped to %%.
+
+    $obj->is_escape_percent_sign(1); # boolean true or false;
 
 =head2 method formatter_code, clear_formatter_code
 
@@ -434,7 +453,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2011 - 2014,
+Copyright (c) 2011 - 2015,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
